# -*- rpm-spec -*-

# This spec file assumes you are building on a Fedora or RHEL version
# that's still supported by the vendor. It may work on other distros
# or versions, but no effort will be made to ensure that going forward
%define min_rhel 7
%define min_fedora 29

%if (0%{?fedora} && 0%{?fedora} >= %{min_fedora}) || (0%{?rhel} && 0%{?rhel} >= %{min_rhel})
    %define supported_platform 1
%else
    %define supported_platform 0
%endif

%define _with_python2 1
%if 0%{?fedora} > 30 || 0%{?rhel} > 7
%define _with_python2 0
%endif

%define _with_python3 0
%if 0%{?fedora} || 0%{?rhel} > 7
%define _with_python3 1
%endif

# Whether py2 packages are assumed to have python2- name prefix
%define py2_versioned_deps 0
%if 0%{?fedora} || 0%{?rhel} > 7
%define py2_versioned_deps 1
%endif

%{!?with_python2: %define with_python2 %{_with_python2}}
%{!?with_python3: %define with_python3 %{_with_python3}}

Summary: The libvirt virtualization API python2 binding
Name: libvirt-python
Version: 6.6.0
Release: 5%{?dist}%{?extra_release}
Epoch: 1000
Source0: %{name}-%{version}.tar.gz
Url: http://libvirt.org
License: LGPLv2+
BuildRequires: libvirt-devel == %{epoch}:%{version}
%if %{with_python2}
%if %{py2_versioned_deps}
BuildRequires: python2-devel
BuildRequires: python2-nose
BuildRequires: python2-lxml
%else
BuildRequires: python-devel
BuildRequires: python-nose
BuildRequires: python-lxml
%endif
%endif
%if %{with_python3}
BuildRequires: python3-devel
BuildRequires: python3-nose
BuildRequires: python3-lxml
%endif
BuildRequires: gcc

# Don't want provides for python shared objects
%if %{with_python2}
%{?filter_provides_in: %filter_provides_in %{python2_sitearch}/.*\.so}
%endif
%if %{with_python3}
%{?filter_provides_in: %filter_provides_in %{python3_sitearch}/.*\.so}
%endif
%{?filter_setup}

%description
The libvirt-python package contains a module that permits applications
written in the Python programming language to use the interface
supplied by the libvirt library to use the virtualization capabilities
of recent versions of Linux (and other OSes).

%if %{with_python2}
%package -n python2-libvirt
Summary: The libvirt virtualization API python2 binding
Url: http://libvirt.org
License: LGPLv2+
%{?python_provide:%python_provide python2-libvirt}
Provides: libvirt-python = %{epoch}:%{version}-%{release}
Obsoletes: libvirt-python <= 3.6.0-1%{?dist}

%description -n python2-libvirt
The python2-libvirt package contains a module that permits applications
written in the Python programming language to use the interface
supplied by the libvirt library to use the virtualization capabilities
of recent versions of Linux (and other OSes).
%endif

%if %{with_python3}
%package -n python3-libvirt
Summary: The libvirt virtualization API python3 binding
Url: http://libvirt.org
License: LGPLv2+
%{?python_provide:%python_provide python3-libvirt}
Provides: libvirt-python3 = %{epoch}:%{version}-%{release}
Obsoletes: libvirt-python3 <= 3.6.0-1%{?dist}

%description -n python3-libvirt
The python3-libvirt package contains a module that permits applications
written in the Python programming language to use the interface
supplied by the libvirt library to use the virtualization capabilities
of recent versions of Linux (and other OSes).
%endif

%prep
%setup -q

# Unset execute bit for example scripts; it can introduce spurious
# RPM dependencies, like /usr/bin/python which can pull in python2
# for the -python3 package
find examples -type f -exec chmod 0644 \{\} \;

%build
%if ! %{supported_platform}
echo "This RPM requires either Fedora >= %{min_fedora} or RHEL >= %{min_rhel}"
exit 1
%endif

%if %{with_python2}
%if 0%{?fedora} || 0%{?rhel} >= 8
%py2_build
%else
CFLAGS="$RPM_OPT_FLAGS" %{__python2} setup.py build
%endif
%endif
%if %{with_python3}
%if 0%{?fedora} || 0%{?rhel} >= 8
%py3_build
%else
CFLAGS="$RPM_OPT_FLAGS" %{__python3} setup.py build
%endif
%endif

%install
%if %{with_python2}
%if 0%{?fedora} || 0%{?rhel} >= 8
%py2_install
%else
%{__python2} setup.py install --skip-build --root=%{buildroot}
%endif
%endif
%if %{with_python3}
%if 0%{?fedora} || 0%{?rhel} >= 8
%py3_install
%else
%{__python3} setup.py install --skip-build --root=%{buildroot}
%endif
%endif

%check
%if %{with_python2}
%{__python2} setup.py test
%endif
%if %{with_python3}
%{__python3} setup.py test
%endif

%if %{with_python2}
%files -n python2-libvirt
%doc ChangeLog AUTHORS README COPYING COPYING.LESSER examples/
%{python2_sitearch}/libvirt.py*
%{python2_sitearch}/libvirt_qemu.py*
%{python2_sitearch}/libvirt_lxc.py*
%{python2_sitearch}/libvirtmod*
%{python2_sitearch}/*egg-info
%endif

%if %{with_python3}
%files -n python3-libvirt
%doc ChangeLog AUTHORS README COPYING COPYING.LESSER examples/
%{python3_sitearch}/libvirt.py*
%{python3_sitearch}/libvirtaio.py*
%{python3_sitearch}/libvirt_qemu.py*
%{python3_sitearch}/libvirt_lxc.py*
%{python3_sitearch}/__pycache__/libvirt.cpython-*.py*
%{python3_sitearch}/__pycache__/libvirt_qemu.cpython-*.py*
%{python3_sitearch}/__pycache__/libvirt_lxc.cpython-*.py*
%{python3_sitearch}/__pycache__/libvirtaio.cpython-*.py*
%{python3_sitearch}/libvirtmod*
%{python3_sitearch}/*egg-info
%endif


%changelog
* Sat Oct 02 2021 Qubes OS Team <qubes-devel@googlegroups.com>
- For complete changelog see: https://github.com/QubesOS/qubes-core-libvirt.git

* Sat Oct 02 2021 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - ff99a64
- version 6.6.0-5

* Tue Sep 28 2021 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 65d4c38
- Redude dependencies of the libvirt-daemon-xen package

* Mon Jun 21 2021 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 666e4cc
- version 6.6.0-4

* Sun Jun 20 2021 Dmitry Fedorov <d.fedorov@tabit.pro> - aaa6bde
- winusb: release memory for emulator's strings

* Sun Jun 20 2021 Dmitry Fedorov <d.fedorov@tabit.pro> - 18a7376
- winusb: fail if kernel or ramdisk not found

* Sat Jun 19 2021 Dmitry Fedorov <d.fedorov@tabit.pro> - ae1cdab
- winusb: add missing patch

* Tue Jun 01 2021 Demi Marie Obenour <demi@invisiblethingslab.com> - 248fd70
- Switch from wget to curl

* Tue Jan 19 2021 Dmitry Fedorov <d.fedorov@tabit.pro> - a9565c7
- winusb: Add ability to configure emulator kernel and ramdisk path

* Sun Nov 15 2020 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - 737587e
- Add .gitlab-ci.yml

* Thu Sep 10 2020 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 1f0c3ae
- version 6.6.0-2

* Thu Sep 10 2020 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 7c3f675
- Don't use deprecated b_info->u.hvm.{acpi,apic} fields

* Thu Aug 20 2020 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - b9620d1
- version 6.6.0-1

* Thu Aug 20 2020 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - eb8e668
- New releases are signed by Jiri Denemark - add the key

* Sat Jun 20 2020 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - f2ee972
- Update to 6.4.0

* Sat Jun 20 2020 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - dc700d9
- travis: disable verbose logging during build

* Mon May 18 2020 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - ec3deb5
- spec: escape '%' in comments

* Sun May 17 2020 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - 86640e7
- Update .travis.yml

* Thu May 07 2020 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - cfedef8
- Update to 6.3.0

* Tue Apr 28 2020 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - 6591607
- spec: remove libvirt-tls and libvirt-tcp

* Sun Apr 12 2020 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - b5371ea
- spec: set epoch to 1000

* Sun Jan 19 2020 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 277eee8
- Update to 6.0.0

* Sat Jan 11 2020 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - 9e8ced9
- travis: switch to dom0 Fedora 31

* Sat Jan 04 2020 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 36d8a9e
- version 5.7.0-3

* Thu Oct 24 2019 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - 5eef125
- Reload libxl otherwise libvirt will use old libraries after update

* Thu Oct 24 2019 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 85870fb
- Disable virnetsockettest, as it's incompatible with build environment

* Sat Oct 19 2019 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - d59222a
- travis: switch to bionic

* Sun Sep 29 2019 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - ef04ff3
- version 5.7.0-2

* Sat Sep 07 2019 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - c62b63d
- spec: sync libvirt-python with upstream

* Sat Sep 07 2019 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 33b0fa3
- Update to 5.7.0

* Sat Sep 07 2019 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - fc22615
- Fix libxlDomainPMSuspendForDuration

* Tue Feb 26 2019 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 4b13582
- version 5.0.0-2

* Tue Feb 26 2019 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 8f37050
- rpm: do not expand macros in comments in libvirt-python.spec

* Tue Feb 26 2019 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 9049853
- rpm: add BR: gcc to libvirt-python too

* Tue Feb 26 2019 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 8684fb5
- travis: reduce verbosity

* Tue Feb 26 2019 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - d14585b
- travis: update to R4.1

* Sat Feb 09 2019 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - a4a8e0a
- rpm: depend on new enough xen-libs

* Sat Feb 09 2019 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 1f611d6
- Update to libvirt 5.0.0

* Tue Feb 05 2019 Frédéric Pierret (fepitre) <frederic.epitre@orange.fr> - f1ee524
- libvirt-python.spec.in: update with respect to upstream

* Tue Feb 05 2019 fepitre <frederic.epitre@orange.fr> - 424a120
- Remove patches which are in upstream

* Wed Dec 26 2018 Frédéric Pierret (fepitre) <frederic.epitre@orange.fr> - 3058a5b
- Use @REL1@ for libvirt-python

* Mon Oct 01 2018 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 30a6699
- rpm: add missing BR: git

* Sun Jul 29 2018 Frédéric Pierret <frederic.epitre@orange.fr> - f1b332e
- Support DISTFILES_MIRROR

* Thu Jul 19 2018 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 4fb46c5
- Remove unused patches

* Tue May 15 2018 Simon Gaiser <simon@invisiblethingslab.com> - 3ec41ce
- Add new qubes-gui options

* Tue Apr 03 2018 Frédéric Pierret <frederic.epitre@orange.fr> - 385f8f3
- spec.in: add changelog placeholder

* Mon Apr 02 2018 Frédéric Pierret <frederic.epitre@orange.fr> - 8489a3d
- Create .spec.in

* Fri Jan 26 2018 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 3b644f8
- version 3.3.0-7

* Fri Jan 26 2018 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 0e4a2b5
- rpm: update dependencies for type=pvh config change

* Wed Jan 24 2018 Simon Gaiser <simon@invisiblethingslab.com> - 32abc70
- Add support for type=pvh

* Mon Jan 22 2018 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - e5d7dc5
- version 3.3.0-6

